@@ -10,12 +10,12 @@ closure.set <-
 function(x, operation = c("union", "intersection"), ...)
 {
     if (length(x) < 2L) return(x)
-    if (!all(sapply(x, is.gset)))
-        stop("closure only defined on set of (g)sets.")
+    if (!all(sapply(x, is.cset)))
+        stop("closure only defined on set of (c,g)sets.")
 
     if (all(sapply(x, is.set))) {
 
-        dom <- as.list(do.call(set_union, x))
+        dom <- .as.list(do.call(set_union, x))
         x <- lapply(x, .make_list_elements)
 
         members <-
@@ -27,7 +27,7 @@ function(x, operation = c("union", "intersection"), ...)
                                              )
                                        )
                             )
-    } else {
+    } else if (all(sapply(x, is.gset))) {
         operation <- paste("gset_", match.arg(operation), sep = "")
         len <- 0
         while ((newlen <- length(gset_support(x))) != len) {
@@ -39,6 +39,18 @@ function(x, operation = c("union", "intersection"), ...)
                    )
         }
         x
+    } else {
+        operation <- paste("cset_", match.arg(operation), sep = "")
+        len <- 0
+        while ((newlen <- length(cset_support(x))) != len) {
+            len <- newlen
+            x <- c(x,
+                   as.set(lapply(cset_combn(x, 2L),
+                                 function(i) do.call(cset_union, i))
+                          )
+                   )
+        }
+        x
     }
 }
 
