@@ -26,11 +26,12 @@ function(...)
     CON <- function(x, y) pmax(0, x - y)
 
     ## compute target support
-    support <- do.call(set_union, l)
+    support <- as.set(l[[1]])
+    if (set_is_empty(support))
+        return(set())
 
     ## apply connector
     .make_gset_from_list_of_gsets_and_support_and_connector(l, support, CON)
-
 }
 
 cset_sum <-
@@ -77,9 +78,12 @@ function(...)
     CON <- function(x, y) pmax(0, x - y)
 
     ## compute target support
-    support <- cset(do.call(set_union, l),
+    support <- cset(as.set(l[[1]]),
                     matchfun = matchfun,
                     orderfun = orderfun)
+    if (cset_is_empty(support))
+        return(support)
+
 
     ## apply connector
     .make_cset_from_gset_and_orderfun_and_matchfun(
